@@ -9,8 +9,8 @@ use std::io::Read;
 fn test_query_creates_xml_on_created_database_with_added_resources() -> Result<(), ClientError> {
     let mut client = Client::connect("localhost", 1984, "admin", "admin")?;
 
-    let info = client.create("lambada")?.without_input()?;
-    assert!(info.starts_with("Database 'lambada' created"));
+    let info = client.create("1cb80e7")?.without_input()?;
+    assert!(info.starts_with("Database '1cb80e7' created"));
 
     let test_xml = Asset::get("sleeping.xml").unwrap();
     let info = client.add("sleeping", &mut test_xml.as_ref())?;
