@@ -5,17 +5,16 @@ use basex::{Client, ClientError};
 
 #[test]
 fn test_query_recognizes_updating_statements() -> Result<(), ClientError> {
-    let mut client = Client::connect("localhost", 1984, "admin", "admin")?;
+    let client = Client::connect("localhost", 1984, "admin", "admin")?;
 
     let mut non_updating_query = client.query(&mut "count(/None/*)".as_bytes())?;
-    let result = non_updating_query.updating()?;
-    assert!(!result);
+    assert!(!non_updating_query.updating()?);
+
+    let client = non_updating_query.close()?;
 
     let mut updating_query = client.query(&mut "replace value of node /None with 1".as_bytes())?;
-    let result = updating_query.updating()?;
-    assert!(result);
+    assert!(updating_query.updating()?);
 
-    let _ = non_updating_query.close()?;
-    let _ = updating_query.close()?;
+    updating_query.close()?;
     Ok(())
 }
