@@ -9,9 +9,9 @@ use std::io::Read;
 fn test_query_runs_on_created_database_with_replaced_resource() -> Result<(), ClientError> {
     let mut client = Client::connect("localhost", 1984, "admin", "admin")?;
 
-    let info = client.create("lambada")?.without_input()?;
+    let info = client.create("0076e54")?.without_input()?;
 
-    assert!(info.starts_with("Database 'lambada' created"), "Actual info: {}", info);
+    assert!(info.starts_with("Database '0076e54' created"), "Actual info: {}", info);
 
     let test_xml = Asset::get("powder.xml").unwrap();
     let info = client.add("sleeping", &mut test_xml.as_ref())?;
